| Title: | Tournament of Champions Data |
|---|---|
| Description: | Several datasets which describe the challenges and results of competitions in Tournament of Champions. This data is useful for practicing data wrangling, graphing, and analyzing how each season of Tournament of Champions played out. |
| Authors: | Levitz Carly [cre, aut] (ORCID: <https://orcid.org/0000-0003-3094-411X>) |
| Maintainer: | Levitz Carly <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-24 07:11:01 UTC |
| Source: | https://github.com/celevitz/tournamentofchampions |
A dataset containing information on each Chef, which is the same for all seasons
data(chefs)data(chefs)
This data frame contains the following columns:
chefChef name (full name)
nicknameGuy Fieri's nickname for the chef
handednessWhether the chef is right-handed, left-handed, or ambidextrous
genderWhether the chef is male, female, or non-binary
totalseasonsnumber of seasons appeared in
inqualifiersnumber of times they were in the qualifiers at the start of the season
inmainbracketnumber of times they were in the main bracket at the start of the season
season1whether they started in the qualifiers or main bracket in season 1. NA values indicate they were not in season 1.
season2whether they started in the qualifiers or main bracket in season 2. NA values indicate they were not in season 2.
season3whether they started in the qualifiers or main bracket in season 3. NA values indicate they were not in season 3.
season4whether they started in the qualifiers or main bracket in season 4. NA values indicate they were not in season 4.
season5whether they started in the qualifiers or main bracket in season 5. NA values indicate they were not in season 5.
season6whether they started in the qualifiers or main bracket in season 6. NA values indicate they were not in season 6.
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse) chefs %>% filter(gender == "female")library(tidyverse) chefs %>% filter(gender == "female")
A dataset containing information about who were the judges for each challenge/episode
data(judges)data(judges)
This data frame contains the following columns:
seasonSeason number
episodeEpisode number
judgeName of guest judge
genderWhether the chef is male, female, or non-binary
roundStage of the tournament: Qualifier semi-final, Qualifier final, Round of 32, Round of 16, Quarterfinals, Semifinals, Final
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse) judges %>% filter(judge == "Ming Tsai") %>% group_by(season,episode)library(tidyverse) judges %>% filter(judge == "Ming Tsai") %>% group_by(season,episode)
A dataset containing information about each challenge: protein, vegetables, equipment, style, time
data(randomizer)data(randomizer)
This data frame contains the following columns:
seasonSeason number
episodeEpisode number
roundStage of the tournament: Qualifier semi-final, Qualifier final, Round of 32, Round of 16, Quarterfinals, Semifinals, Final
challengeVariable to help distinguish challenges within the same Coast & Round
coastEast or West
regionThe region depends on how many chefs start the competition. If there are 16 chefs, then the region is left blank. If there are 32 chefs, then the regions are A or B.
randomizer1First wheel of randomizer
randomizer2Second wheel of randomizer
randomizer3Third wheel of randomizer
randomizer4Fourth wheel of randomizer
timeLength of challenge. Unit is minutes
randomizer5Fifth wheel of randomizer
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse) randomizer %>% group_by(season,episode,challenge,coast) %>% filter(round == "Semi-final")library(tidyverse) randomizer %>% group_by(season,episode,challenge,coast) %>% filter(round == "Semi-final")
A dataset containing information about each challenge: protein, vegetables, equipment, style, time However, it's in "long form" so each challenge shows up multiple times It categorizes the randomizer ingredients into categories and subcategories
data(randomizerlongform)data(randomizerlongform)
This data frame contains the following columns:
seasonSeason number
episodeEpisode number
roundStage of the tournament: Qualifier semi-final, Qualifier final, Round of 32, Round of 16, Quarterfinals, Semifinals, Final
challengeVariable to help distinguish challenges within the same Coast & Round
coastEast or West
regionThe region depends on how many chefs start the competition. If there are 16 chefs, then the region is left blank. If there are 32 chefs, then the regions are A or B.
timeLength of challenge. Unit is minutes
randomizerWhat wheel was spun (1, 2, 3, 4, or 5)
valueWhat was the value/item on the randomizer wheel?
categoryCategorical variable: protein,produce,equipment, style,wildcard
subcategorySubcategories for protein (Beef, Fish, Game, Other, Pork, Poultry, Shellfish) and style (Region/country, Style, Theme)
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse) randomizerlongform %>% filter(category == "protein") %>% group_by(subcategory) %>% summarise(n=n())library(tidyverse) randomizerlongform %>% filter(category == "protein") %>% group_by(subcategory) %>% summarise(n=n())
A dataset containing win and loss data for each chef in each episode
data(results)data(results)
This data frame contains the following columns:
seasonSeason number
episodeEpisode number
roundStage of the tournament: Qualifier semi-final, Qualifier final, Round of 32, Round of 16, Quarterfinals, Semifinals, Final
challengeVariable to help distinguish rounds within the same Coast & Round
coastEast or West
regionThe region depends on how many chefs start the competition. If there are 16 chefs, then the region is left blank. If there are 32 chefs, then the regions are A or B.
chefName of chef
commentatorWho presented their food to the judges: Simon Majumdar or Justin Warner? In Qualifying rounds, it could be presented by Hunter Fieri
orderWhen did their food get presented to the judges: Presented first or Presented second. In Qualifying rounds, it could be presented third or fourth.
score_tasteScore that chef received for the taste of their dish: values of 0- 50
score_randomizerScore that chef received for how well they used the Randomizer: values of 0- 30. (Except in Season 5 Qualifying rounds, the values are 0-40.)
score_presentationScore that chef received for the presentation of their dish: values of 0- 20. (Except in Season 5 Qualifying rounds, the values are 0-10.)
totalTotal score that chef received: between 0 and 100
winnerCategorical variable: Winner, Loser, Tie
xNumeric X value to help with visualizing bracket
yNumeric Y value to help with visualizing bracket
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse) results %>% group_by(season) %>% filter(round == "Final") %>% select(chef,season,coast,total)library(tidyverse) results %>% group_by(season) %>% filter(round == "Final") %>% select(chef,season,coast,total)
A dataset containing game-related information on each Chef for each season.
data(seeds)data(seeds)
This data frame contains the following columns:
chefChef name (full name)
seasonSeason number
seedSeed within their section of the bracket: values of 1 through 8. Chefs that played in the qualifiers but didn't make the final bracket will have seeds of 8.2, 8.3, or 8.4.
coastAre they East or West Coast?
regionThe region depends on how many chefs start the competition. If there are 16 chefs, then the region is left blank. If there are 32 chefs, then the regions are A or B.
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse) seeds %>% filter(season == 1)library(tidyverse) seeds %>% filter(season == 1)